==> renderdoc_1.6+dfsg.orig.tar.xz: renderdoc-1.6/util/test/demos/win32/win32_platform.h <==
/******************************************************************************
* The MIT License (MIT)
*
* Copyright (c) 2019-2020 Baldur Karlsson
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
******************************************************************************/

#pragma once

#define _CRT_SECURE_NO_WARNINGS
#define _CRT_NONSTDC_NO_DEPRECATE
#define NOMINMAX
#include <windows.h>

#include <string>

std::string Wide2UTF8(const std::wstring &s);
std::wstring UTF82Wide(const std::string &s);

#define DEBUG_BREAK()       \
  do                        \
  {                         \
    if(IsDebuggerPresent()) \
      __debugbreak();       \
  } while(0)

#define popen _popen
#define pclose _pclose

#define get_tmpnam tmpnam_s

#define msleep(time) Sleep(time)

#define WEXITSTATUS(code) code

#define EXECUTABLE_SUFFIX ".exe"

==> renderdoc_1.11+dfsg.orig.tar.xz: renderdoc-1.11/util/test/demos/win32/win32_platform.h <==
/******************************************************************************
* The MIT License (MIT)
*
* Copyright (c) 2019-2020 Baldur Karlsson
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
******************************************************************************/

#pragma once

#define _CRT_SECURE_NO_WARNINGS
#define _CRT_NONSTDC_NO_DEPRECATE
#define NOMINMAX
#include <windows.h>

#include <string>

std::string Wide2UTF8(const std::wstring &s);
std::wstring UTF82Wide(const std::string &s);

std::string GetExecutableName();

#define DEBUG_BREAK()       \
  do                        \
  {                         \
    if(IsDebuggerPresent()) \
      __debugbreak();       \
  } while(0)

#define popen _popen
#define pclose _pclose

#define msleep(time) Sleep(time)

#define MakeDir(dir) CreateDirectoryA(dir, NULL)

#define WEXITSTATUS(code) code

#define EXECUTABLE_SUFFIX ".exe"
